import 'package:circlegraph/circlegraph.dart';
import 'package:dashboard/querying/datagetter.dart';
import 'package:dashboard/ui/util/logged_in_appbar.dart';
import 'package:enhanced_future_builder/enhanced_future_builder.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import '../data/community.dart';
import '../data/communityGraphNodeData.dart';
import '../querying/datagetter.dart';
import '../data/post.dart';
import 'postnode.dart';
import 'communitymetagraph.dart';

class CommunityGraph extends StatefulWidget {
  CommunityGraph(this.community);
  final Community community;

  _CommunityGraphState createState() => _CommunityGraphState(community);
}

class _CommunityGraphState extends State<CommunityGraph> {
  _CommunityGraphState(this.community);
  final Community community;

  int nrPerPage = 10;
  int pageNr = 0;

  build(BuildContext context) {
    var nodes = [];

    for (int i = pageNr * nrPerPage;
        (i < pageNr * nrPerPage + nrPerPage) && i < community.posts.length;
        i++) {
      nodes.add(community.posts[i]);
    }

    nodes.add(Post("...", "", "", community.name, community.trust, 69));

    return Container(
      width: 2000,
      height: 1000,
      //constraints: BoxConstraints.expand(),
      child: InteractiveViewer(
        constrained: true,
        boundaryMargin: EdgeInsets.all(100),
        minScale: 0.01,
        maxScale: 5.6,
        child: CircleGraph(
          root: _getCommunityNode(community),
          children: [for (var node in nodes) _getPostNode(node)],
        ),
      ),
    );
  }

  TreeNodeData<CommunityGraphNodeData> _getCommunityNode(Community community) {
    CommunityGraphNodeData data =
        CommunityGraphNodeData.fromCommunity(community);

    return TreeNodeData<CommunityGraphNodeData>(
      child: getCommunityNodeWidget(community.name, community.trust),
      data: data,
      width: 150,
    );
  }

  TreeNodeData<CommunityGraphNodeData> _getPostNode(Post post) {
    CommunityGraphNodeData data = CommunityGraphNodeData.fromPost(post);
    PostNode postNode = PostNode(post);

    return TreeNodeData<CommunityGraphNodeData>(
      child: postNode,
      data: data,
      width: 250,
    );
  }

  Widget getCommunityNodeWidget(String name, double trustvalue) {
    return Row(
      children: [
        Expanded(
          child: Text(
            name,
            overflow: TextOverflow.ellipsis,
            style: TextStyle(fontWeight: FontWeight.bold, color: Colors.black),
          ),
        ),
        Text(
          (trustvalue * 100).toString() + "%",
          style: TextStyle(fontWeight: FontWeight.bold, color: Colors.green),
        ),
      ],
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
    );
  }
}

class CommunityGraphViewPage extends StatelessWidget {
  final String communityname;

  CommunityGraphViewPage(this.communityname);

  Widget build(BuildContext context) {
    return Scaffold(
        appBar: LoggedInAppBar(),
        backgroundColor: Colors.white,
        floatingActionButton: FloatingActionButton(
          onPressed: () => redirectToCommunityMetaGraph(context),
          child: Icon(Icons.zoom_out),
        ),
        body: Container(
          padding: EdgeInsets.all(12),
          constraints: BoxConstraints.expand(),
          child: Column(
            mainAxisSize: MainAxisSize.max,
            children: [
              Wrap(
                children: [],
              ),
              EnhancedFutureBuilder(
                  future: DataGetter.getCommunity(communityname),
                  rememberFutureResult: false,
                  whenDone: (result) => CommunityGraph(result),
                  whenNotDone: Container(
                      alignment: Alignment.center, child: Text("Loading..."))),
            ],
          ),
        ));
  }

  void redirectToCommunityMetaGraph(BuildContext context) {
    Navigator.push(
        context,
        MaterialPageRoute(
          builder: (context) => CommunityMetaGraphViewPage(),
        ));
  }
}
