import 'package:circlegraph/circlegraph.dart';
import 'package:dashboard/data/communityGraphNodeData.dart';
import 'package:dashboard/querying/datagetter.dart';
import 'package:dashboard/graphing/postnode.dart';
import 'package:flutter/material.dart';
import 'package:logger/logger.dart';
import '../data/community.dart';
import '../data/post.dart';
import 'postnode.dart';
import 'trustcolorcalculator.dart';
import 'package:enhanced_future_builder/enhanced_future_builder.dart';

class CommunityMetaGraph extends StatefulWidget {
  final List<Community> communities;
  CommunityMetaGraph(this.communities);

  _CommunityMetaGraphState createState() =>
      _CommunityMetaGraphState(this.communities);
}

class _CommunityMetaGraphState extends State<CommunityMetaGraph> {
  final List<Community> communities;
  int postNodeCount = 10; // Nr of postNodes displayed
  _CommunityMetaGraphState(this.communities);

  Widget build(BuildContext context) {
    Logger().i(communities.toString());
    return Container(
      width: 2000,
      height: 1000,
      //constraints: BoxConstraints.expand(),
      child: InteractiveViewer(
        constrained: true,
        boundaryMargin: EdgeInsets.all(100),
        minScale: 0.01,
        maxScale: 5.6,
        child: BubbleGraph(
          [
            for (Community community in communities)
              CircleGraph(
                root: _getCommunityNode(community),
                children: [
                  for (Post post in community.posts) _getPostNode(post)
                ],
              )
          ],
        ),
      ),
    );
  }

  TreeNodeData<CommunityGraphNodeData> _getCommunityNode(Community community) {
    CommunityGraphNodeData data =
        CommunityGraphNodeData.fromCommunity(community);

    return TreeNodeData(
      child: getCommunityNodeWidget(community),
      data: data,
      width: 500,
    );
  }

  TreeNodeData<CommunityGraphNodeData> _getPostNode(Post post) {
    CommunityGraphNodeData data = CommunityGraphNodeData.fromPost(post);

    return TreeNodeData<CommunityGraphNodeData>(
      child: PostNode(post),
      data: data,
      width: 500,
    );
  }

  Widget getCommunityNodeWidget(Community community) {
    return GestureDetector(
        child: Row(
      children: [
        Expanded(
          child: Text(
            community.name,
            overflow: TextOverflow.ellipsis,
            style: TextStyle(fontWeight: FontWeight.bold, color: Colors.black),
          ),
        ),
        Text(
          (community.trust * 100).toString() + "%",
          style: TextStyle(
              fontWeight: FontWeight.bold,
              color: TrustColorCalculator.calculateTrustColor(community.trust)),
        ),
      ],
      mainAxisAlignment: MainAxisAlignment.spaceBetween,
    ));
  }
}

class CommunityMetaGraphViewPage extends StatelessWidget {
  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        //floatingActionButton: FloatingActionButton(
        //  onPressed: () => print("hoe"),
        //  child: Icon(Icons.zoom_in),
        //),
        body: Container(
          padding: EdgeInsets.all(12),
          constraints: BoxConstraints.expand(),
          child: Column(
            mainAxisSize: MainAxisSize.max,
            children: [
              EnhancedFutureBuilder(
                future: DataGetter.getCommunities(),
                rememberFutureResult: false,
                whenDone: (communities) => CommunityMetaGraph(communities),
                whenNotDone: Container(
                  alignment: Alignment.center,
                  child: Text("Loading..."),
                ),
              ),
            ],
          ),
        ));
  }
}
