import 'package:circlegraph/circlegraph.dart';
import 'package:dashboard/querying/datagetter.dart';
import 'package:enhanced_future_builder/enhanced_future_builder.dart';
import 'package:flutter/cupertino.dart';

import 'package:flutter/material.dart';
import '../data/post.dart';
import '../data/userGraphNodeData.dart';
import 'usernode.dart';
import 'postnode.dart';
import '../data/user.dart';

class UserGraph extends StatefulWidget {
  UserGraph(this.user);
  final User user;

  @override
  _UserGraphState createState() => _UserGraphState(user);
}

class _UserGraphState extends State<UserGraph> {
  _UserGraphState(this.user);
  final User user;

  int nrPerPage = 15;
  int pageNr = 0;

  Widget build(BuildContext context) {
    List<Post> nodes = [];

    for (int i = pageNr * nrPerPage;
        (i < pageNr * nrPerPage + nrPerPage) && i < user.posts.length;
        i++) {
      nodes.add(user.posts[i]);
    }

    return Container(
      //constraints: BoxConstraints.expand(),
      child: InteractiveViewer(
          constrained: true,
          boundaryMargin: EdgeInsets.all(100),
          minScale: 0.01,
          maxScale: 5.6,
          child: CircleGraph(
            root: _getUserNode(user),
            children: [for (Post post in nodes) _getPostNode(post)],
          )),
    );
  }

  TreeNodeData<UserGraphNodeData> _getUserNode(User user) {
    UserGraphNodeData data = UserGraphNodeData.fromUser(user);

    return TreeNodeData(
        child: UserNode(user.trustScores),
        data: data,
        backgroundColor: Colors.transparent);
  }

  TreeNodeData<UserGraphNodeData> _getPostNode(Post post) {
    UserGraphNodeData data = UserGraphNodeData.fromPost(post);

    return TreeNodeData(child: PostNode(post), data: data);
  }
}

class UserGraphViewPage extends StatelessWidget {
  UserGraphViewPage(this.username);
  final String username;

  Widget build(BuildContext context) {
    return Scaffold(
        backgroundColor: Colors.white,
        body: Container(
          constraints: BoxConstraints.expand(),
          child: Column(
            mainAxisSize: MainAxisSize.max,
            children: [
              EnhancedFutureBuilder<User>(
                  future: DataGetter.getUser(username),
                  // future: DataGetter.getJson(
                  //     "http://live.nope-api.systems:81/users/" +
                  //         username.toString()),
                  rememberFutureResult: false,
                  whenDone: (result) => UserGraph(result),
                  whenNotDone: Container(
                      alignment: Alignment.center, child: Text("loading..."))),
            ],
          ),
        ));
  }
}
