import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:logger/logger.dart';

import 'package:dashboard/data/community.dart';
import 'package:dashboard/data/post.dart';
import 'package:dashboard/data/user.dart';

class DataGetter {
  static Future<Map<String, dynamic>> getJson(String url,
      {Map<String, dynamic> headers}) async {
    http.Response response;
    if (headers == null) {
      response = await http.get(url);
    } else {
      response = await http.get(url, headers: headers);
    }

    if (response.statusCode != 200) {
      Logger().e("Http request code != 200");
      throw HttpException(
          "Status code is not 200 but " + response.statusCode.toString());
    }

    return jsonDecode(response.body) as Map<String, dynamic>;
  }

  static Future<Map<String, dynamic>> postJson(String url, String body,
      {Map<String, dynamic> headers}) async {
    http.Response response;

    print(url + "\n" + body);
    if (headers == null) {
      response = await http.post(url, body: body);
    } else {
      response = await http.post(url, body: body, headers: headers);
    }

    if (response.statusCode != 200) {
      throw HttpException(
          "Status code is not 200 but " + response.statusCode.toString());
    }

    return jsonDecode(response.body) as Map<String, dynamic>;
  }

  static Future<User> getUser(String username) async {
    String url = "http://live.nope-api.systems:81/users/$username";

    Map<String, dynamic> json = await getJson(url);

    //getJson(url).then((value) => json = value);

    int id = json["user"]["id"];

    Map<String, dynamic> trustscores = json["trust_scores"];

    Map<String, dynamic> postCommunityMap = json["posts"];

    List<Post> postList = [];
    postCommunityMap.forEach((community, postjson) {
      List<dynamic> postMapList = postjson;
      postList.addAll(_getPostListFromMapList(postMapList));
    });

    return User(username, id, trustscores, postList);
  }

  static Future<Community> getCommunity(String communityname) async {
    String url =
        "http://live.nope-api.systems:81/communities/$communityname/posts";

    Map<String, dynamic> json = await getJson(url);

    double trust = json["trust"];

    List<dynamic> postMapList = json["posts"];
    List<Post> postList = _getPostListFromMapList(postMapList);

    return Community(communityname, trust, postList);
  }

  static List<Post> _getPostListFromMapList(List<dynamic> postMapList) {
    List<Post> postList = [];

    for (Map<String, dynamic> postMap in postMapList) {
      Post post = Post(
          postMap["title"],
          postMap["content"],
          postMap["user_id"],
          postMap["subreddit"],
          postMap["percentage_upvoted"],
          postMap["n_comments"]);

      postList.add(post);
    }

    return postList;
  }

  static Future<List<Community>> getCommunities() async {
    Map<String, dynamic> communities =
        await DataGetter.getJson("http://live.nope-api.systems:81/communities");

    Logger().i(communities.toString());

    List<Community> communityList = [];
    communities.forEach((community, value) async {
      Community results = await getCommunity(community);
      Logger().i(results.toString());
      communityList.add(results);
    });
    Logger().i(communityList.toString());
    return communityList;
  }
}
