import 'package:flutter/material.dart';

class LoginForm extends StatefulWidget {
  @override
  _LoginFormState createState() => _LoginFormState();

  final Function(String, String) loginAttempt;
  final String error;
  final bool isBusy;

  LoginForm(this.loginAttempt, this.error, this.isBusy);
}

class _LoginFormState extends State<LoginForm> {
  String _username = "";
  String _password = "";

  void _submit() {
    if (!widget.isBusy) widget.loginAttempt(_username, _password);
  }

  @override
  Widget build(BuildContext context) {
    return FocusTraversalGroup(
      policy: OrderedTraversalPolicy(),
      child: FractionallySizedBox(
        widthFactor: .6,
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: [
            Image.asset(
              "assets/articonf-logo.png",
            ),
            SizedBox(height: 32),
            TextField(
              readOnly: widget.isBusy,
              autofocus: true,
              decoration: InputDecoration(
                hintText: "Username",
                counterText: "",
                border: OutlineInputBorder(
                  borderRadius: BorderRadius.circular(5.0),
                  borderSide: BorderSide(
                    color: Colors.blue,
                    style: BorderStyle.solid,
                  ),
                ),
              ),
              onChanged: (content) => _username = content,
              minLines: 1,
              maxLines: 1,
              maxLength: 50,
            ),
            SizedBox(height: 16),
            TextField(
              readOnly: widget.isBusy,
              autofocus: false,
              obscureText: true,
              decoration: InputDecoration(
                hintText: "Password",
                counterText: "",
                border: OutlineInputBorder(
                  borderRadius: BorderRadius.circular(5.0),
                  borderSide: BorderSide(
                    color: Colors.blue,
                    style: BorderStyle.solid,
                  ),
                ),
              ),
              onChanged: (content) => _password = content,
              minLines: 1,
              maxLines: 1,
              maxLength: 50,
            ),
            // error message
            if (widget.error != null && widget.error.isNotEmpty)
              Padding(
                padding: const EdgeInsets.only(bottom: 16.0),
                child: Text(
                  widget.error,
                  style: TextStyle(color: Colors.red),
                ),
              ),
            // login button
            SizedBox(height: 16),
            TextButton.icon(
              onPressed: _submit,
              icon: Icon(
                Icons.login,
                size: 32,
                color: Colors.white,
              ),
              label: Text(
                "Sign In",
                style: TextStyle(fontSize: 20, color: Colors.white),
              ),
              style: TextButton.styleFrom(
                backgroundColor: widget.isBusy
                    ? Colors.grey
                    : Theme.of(context).primaryColor,
                padding: EdgeInsets.all(18),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
