import 'package:dashboard/exceptions/login_exception.dart';
import 'package:dashboard/main.dart';
import 'package:dashboard/ui/sign_in/login_form.dart';
import 'package:dashboard/util/loginhelper.dart';
import 'package:dashboard/util/user.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'package:logger/logger.dart';

class LoginPage extends StatefulWidget {
  LoginPage();
  @override
  _LoginPageState createState() => _LoginPageState();
}

class _LoginPageState extends State<LoginPage> {
  String _error;
  bool _isBusy = false;

  final Logger logger = Logger();

  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        decoration: BoxDecoration(
          gradient: LinearGradient(
            colors: [
              Colors.blue[300],
              Colors.blue,
            ],
          ),
        ),
        padding: EdgeInsets.symmetric(horizontal: 32, vertical: 64),
        child: Container(
          color: Colors.white,
          child: Row(
            children: [
              Expanded(
                flex: 4,
                child: Container(
                  child: LoginForm(tryLogin, _error, _isBusy),
                ),
              ),
              Expanded(
                flex: 3,
                child: Container(
                  constraints: BoxConstraints.expand(),
                  child: Stack(
                    children: [
                      Container(
                        constraints: BoxConstraints.expand(),
                        child: Image.asset(
                          "assets/login_image.jpg",
                          fit: BoxFit.cover,
                          alignment: Alignment(-.2, 0),
                        ),
                      ),
                      Container(
                        color: Color.fromRGBO(33, 150, 243, .5),
                      ),
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  ///
  /// attempts to receive a token from the server
  ///
  void tryLogin(String username, String password) async {
    logger.i("Loggin Attempt($username, ******)");

    setState(() {
      _error = "";
      _isBusy = true;
    });

    BackendUser user;

    await Future.delayed(Duration(seconds: 1));

    try {
      user = await LoginHelper().login(username, password);
    } on LoginException catch (e) {
      setState(() {
        _error = e.message;
        _isBusy = false;
      });
      return;
    }

    logger.i("token: ${user.token}");

    // restart app (should login automatically)
    Navigator.of(context).pushReplacement(
      MaterialPageRoute(
        builder: (context) => MyApp(),
      ),
    );
  }
}
